;; Generated package description from websocket.el  -*- no-byte-compile: t -*-
(define-package "websocket" "1.13.1.0.20210110.134234" "Emacs WebSocket client and server" '((cl-lib "0.5")) :authors '(("Andrew Hyatt" . "ahyatt@gmail.com")) :maintainer '("Andrew Hyatt" . "ahyatt@gmail.com") :keywords '("communication" "websocket" "server") :url "https://github.com/ahyatt/emacs-websocket")
